@@ -16,7 +16,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: Detector.pm,v 1.6 2007/01/11 15:11:38 djschaap Exp $
+# $Id: Detector.pm,v 1.8 2007/07/12 23:40:58 evertonm Exp $
 
 package fetchconfig::model::Detector; # fetchconfig/model/Detector.pm
 
@@ -26,6 +26,7 @@ use fetchconfig::model::CiscoIOS;
 use fetchconfig::model::CiscoCAT;
 use fetchconfig::model::FortiGate;
 use fetchconfig::model::ProCurve;
+use fetchconfig::model::Parks;
 
 my $logger;
 my %model_table;
@@ -133,6 +134,7 @@ sub init {
     $class->register(fetchconfig::model::CiscoCAT->new($log));
     $class->register(fetchconfig::model::FortiGate->new($log));
     $class->register(fetchconfig::model::ProCurve->new($log));
+    $class->register(fetchconfig::model::Parks->new($log));
 }
 
 1;
